#
# p0f - RST+ signatures
# ---------------------
#
# .-------------------------------------------------------------------------.
# | The purpose of this file is to cover signatures for reset packets       |
# | (RST and RST+ACK). This mode of operation can be enabled with -A option |
# | and is considered to be least accurate. Please refer to p0f.fp for more |
# | information on the metrics used and for a guide on adding new entries   |
# | to this file. This database is looking for a caring maintainer.         |
# `-------------------------------------------------------------------------'
#
# (C) Copyright 2000-2003 by Michal Zalewski <lcamtuf@coredump.cx>
#
# Submit all additions to the authors. Read p0f.fp before adding any
# signatures. Run p0f -R -C after making any modifications. This file is
# NOT compatible with SYN or SYN+ACK modes. Use only with -R option.
#
# RST packets are sent in response to unwanted TCP/IP packets (although
# some systems, most notably Windows, use it also to drop connections on
# timeout). When the original packet that triggered RST had ACK set, the
# response is simply RST. When the original packet had no ACK set, the
# response is RST+ACK. Below is a discussion of the most common RST types:
#
# - "Connection refused". This port is closed. RST+ACK response to SYN
#   packet. This is the most common type of traffic, and can be triggered
#   obviously by connecting to a closed port. Quite unfortunately, those
#   packets are usually not of a great value to p0f, because many systems
#   just generates dummy, minimaal packets with no options and so on.
#   As a result, this is the least accurate method of RST fingerprinting.
#
#   Note: RST+ACK can also occur in some other situations. The obvious
#   option is handshake snafu, but I don't think it accounts for all the
#   RST+ACK traffic. There are some quite verbose RST+ACK packets, it'd
#   be good to find out what they are. See "mystery responses" group.
#   Timestamps, WSS, all that.
#
#   Note 2: some lesser systems reply with RST to just about anything.
#
# - "You're out". Sometimes, when a timeout or other critical condition
#   occurs, the other system drops a connection from his state table and
#   sends plain RST. I'm not quite sure it's RFC-compliant, but Windows
#   does that, so do some other systems. Plain RST can also occur if
#   something goes bad during the handshake, but it's uncommon. This 
#   can be triggered, by, well, stalling on a connection. 
#
# - "What?". When a system already dropped a connection and did not
#   expect any further transfers to occur, but it received a packet.
#   The response is RST. This is perhaps more valuable kind of packets,
#   and can be of course used for network troubleshooting, but can be
#   also quite quietly induced (see test/sendack.c).
#
# It is important to denote the condition which generated this specific
# packet when adding a signature here. This way, this database becomes
# also a valuable addition for network troubleshooting.
#
# Differences in comparison to p0f.fp data:
#
# - A new quirk, 'K', is introduced to denote RST+ACK packets (as opposed
#   to plain RST). This quirk is only compatible with this mode.
#
# - 'D' quirk is not a bug; some devices send verbose text messages
#   describing why a connection got dropped; it's actually recommended by
#   the RFC.
#
# - 'A' quirk may show on RST+ACK ('K') signatures. Of course, Windows
#   would have non-zero ACK and no ACK flag, why not?
#

################################
# Connection refused - RST+ACK #
################################

0:255:0:40:.:KA:Linux:2.0/2.2 (refused)
0:255:1:40:.:KZA:Linux:sometimes recent 2.4 (refused)
0:64:1:40:.:KZA:Linux:recent 2.4 (refused)
0:64:1:40:.:KA:FreeBSD:4.x (refused)
%4:64:1:40:.:KA:FreeBSD:4.x odd (refused?)
0:128:1:40:.:KA:Windows:XP/2000 (refused?)
0:128:1:40:.:KUA:Windows:XP/2000 while browsing (refused?)

#######################################################
# Mystery responses - RST+ACK in the middle of a chat #
#######################################################

%88:64:1:52:N,N,T:KAT:Linux:2.4 (mystery)
%80:64:0:40:.:KA:Windows:95 (mystery)
S6:128:1:40:.:.:Windows:XP/2000 (mystery)
S32:255:0:40:.:KA:Cisco:Content Engine (mystery)
%10:64:1:40:.:KA:FreeBSD:4.x (mystery)

######################################
# Connection dropped / timeout - RST #
######################################

0:255:1:40:.:Z:Linux:sometimes 2.4 (dropped)
0:64:1:40:.:Z:Linux:recent 2.4 (dropped)

0:128:1:40:.:A:Windows:XP/2000 (dropped)
0:128:1:40:.:UA:Windows:XP/2000 while downloading (dropped)
0:128:1:40:.:.:Windows:9x or NT? (dropped)
0:128:1:40:.:ZA:Windows:98 (dropped)
0:32:1:40:.:A:Windows:95 (low TTL) (dropped)

0:64:0:40:.:.:OpenBSD:3.x or BSD/OS (dropped)
0:64:1:40:.:.:FreeBSD:4.x or Solaris 8 (dropped)

32768:255:1:54:.:D:MacOS:9.x (dropped)

0:255:1:54:.:D:MacOS:9.x (short) (dropped)
0:255:1:58:.:D:MacOS:9.x (mid) (dropped)
0:255:1:62:.:D:MacOS:9.x (long) (dropped)
0:255:1:67:.:D:MacOS:9.x (anchor) (dropped)

648:255:1:54:.:D:MacOS:one really odd 9.x (dropped)

S44:255:1:40:.:.:Solaris:7 (dropped)
17820:64:1:40:.:.:Solaris:8 (1) (dropped)
S12:64:1:40:.:.:Solaris:8 (2) (dropped)

0:255:0:40:.:.:Cisco:Content Engine (dropped)

###################
# Other responses #
###################

0:255:0:40:.:K:-Linux:2.0/2.2 (response to NULL scan)
0:64:1:40:.:KZ:-Linux:2.4 (response to NULL scan)
0:64:1:40:.:K:-FreeBSD:4.x (response to NULL scan)

1024:32:0:60:W10,N,M265,T,E:KPA:-*NMAP:OS fingerprinting reply (1)
2048:32:0:60:W10,N,M265,T,E:KPA:-*NMAP:OS fingerprinting reply (2)
3072:32:0:60:W10,N,M265,T,E:KPA:-*NMAP:OS fingerprinting reply (3)
4096:32:0:60:W10,N,M265,T,E:KPA:-*NMAP:OS fingerprinting reply (4)

